@@ -3,7 +3,7 @@ timeSeries<-
 			 dateformat,
 			 data=NULL,
 			 tz="GMT"){
-		if(class(as.vector(data))!="numeric")stop("Data must be numeric")		
+		if(!is.null(data)&&class(as.vector(data))!="numeric")stop("Data must be numeric")		
 		if(class(data)=="numeric")data.length=length(data)else data.length=length(data[,1])
 		if(!is.null(data)&&length(dates)!=data.length)
 			stop("Lengths differ between dates (",length(dates),") and data (",data.length, ").")
